pub struct StandardTextBlock {
pub headline: Option<Box<TextComponent>>,
pub body: Option<Box<ParagraphComponent>>,
}Expand description
StandardTextBlock : The A+ Content standard text box block, comprised of a paragraph with a headline.
Fields
headline: Option<Box<TextComponent>>body: Option<Box<ParagraphComponent>>Implementations
sourceimpl StandardTextBlock
impl StandardTextBlock
sourcepub fn new() -> StandardTextBlock
pub fn new() -> StandardTextBlock
The A+ Content standard text box block, comprised of a paragraph with a headline.